@@ -738,6 +738,7 @@ class SyncScheduleSnowflakeTask(SubscriptableBaseModel):
         sync_frequency (str): The cron expression for this schedule
         sync_frequency_name (str): The plain english name for this cron schedule
         warehouse (str): The Snowflake warehouse which this task uses
+        time_limit_mins (int): The maximum time the sync can run for before being cancelled
         daily_hour (Optional[int]): If the sync frequency is Daily, the hour it runs
         daily_minute (Optional[int]): If the sync frequency is Daily, the minute it runs
         minute_of_hour (Optional[int]): If the sync frequency is Hourly, the minute of the hour it runs
@@ -748,6 +749,7 @@ class SyncScheduleSnowflakeTask(SubscriptableBaseModel):
     sync_frequency: str
     sync_frequency_name: Literal["1 min", "5 mins", "15 mins", "Hourly", "Daily","Custom"]
     warehouse: str = None
+    time_limit_mins: int = 60 * 4
     daily_hour: Optional[int] = None
     daily_minute: Optional[int] = None
     minute_of_hour: Optional[int] = None
@@ -761,6 +763,7 @@ class SyncScheduleDbt(SubscriptableBaseModel):
         dbt_prod_target_name (str): The name of the dbt target used for production runs
         task_warehouse_dbt_defined (bool): If true, the dbt package will set the schedule settings
         warehouse (str): The Snowflake warehouse which this task uses. If task_warehouse_dbt_defined is True, this is only an initial default before the first run occurs
+        time_limit_mins (int): The maximum time the sync can run for before being cancelled
         dbt_dev_target_name (str): The name of the dbt target used by developers outside of CI
         dbt_sync_model_name (str): The name of the dbt model used to run the sync
         dbt_source_model_name (str): The name of the dbt model used as a source for the run. This will be resolved at runtime and replaces the configured source table
@@ -771,6 +774,7 @@ class SyncScheduleDbt(SubscriptableBaseModel):
     dbt_prod_target_name: str = "prod"
     task_warehouse_dbt_defined: bool = True
     warehouse: str
+    time_limit_mins: int = 60 * 4
     dbt_dev_target_name: str = "dev"
     dbt_sync_model_name: str
     dbt_source_model_name: str
@@ -784,6 +788,7 @@ class SyncScheduleDependant(SubscriptableBaseModel):
     Args:
         run_when (Literal["after_parent_completes","at_same_time_as"]): Determines if this sync runs at the same time as the parent, or after it completes
         warehouse (str): The Snowflake warehouse which this task uses
+        time_limit_mins (int): The maximum time the sync can run for before being cancelled
         selected_sync (int): The sync ID of the sync to depend on
     """
 
@@ -792,6 +797,7 @@ class SyncScheduleDependant(SubscriptableBaseModel):
         "after_parent_completes", "at_same_time_as"
     ] = "after_parent_completes"
     warehouse: str
+    time_limit_mins: int = 60 * 4
     selected_sync: int
 
 
@@ -801,10 +807,12 @@ class SyncScheduleManual(SubscriptableBaseModel):
 
     Args:
         warehouse (str): The Snowflake warehouse which this task uses
+        time_limit_mins (int): The maximum time the sync can run for before being cancelled
     """
 
     mode: Literal["manual"]
     warehouse: str
+    time_limit_mins: int = 60 * 4
 
 
 SyncSchedule = Annotated[
