@@ -264,10 +264,17 @@ class SyncRequest(ABC):
 
     def __cancel_checking_worker(self, cancellation_token:threading.Event):
         """
-        Designed to be run in a thread, this method checks to see if the sync run has been cancelled.
+        Designed to be run in a thread, this method checks to see if the sync run has been cancelled
+        or if the deadline has been reached.
+        Previously this was being done in the managed_inbound_processing and managed_outbound_processing
+        workers, but that meant it's not being checked when the plugin doesn't use those decorators.
         """
         while not cancellation_token.is_set():
-            logger.info("cancel checking worker checking for results")
+            logger.info("cancel checking worker checking for cancellation")
+            if (datetime.datetime.now(datetime.timezone.utc) > self._run_deadline):  # pylint: disable=protected-access
+                # if we've reached the deadline for the run, end it
+                self.apply_deadline_reached()  # pylint: disable=protected-access
+                return
 
             with self._snowflake_query_lock:
                 try:
@@ -1494,12 +1501,6 @@ def __managed_outbound_processing_worker(
         assert (
             plugin_class_obj._sync_request is not None
         )  # pylint: disable=protected-access
-        if (
-            datetime.datetime.now(datetime.timezone.utc) > plugin_class_obj._sync_request._run_deadline
-        ):  # pylint: disable=protected-access
-            # if we've reached the deadline for the run, end it
-            plugin_class_obj._sync_request.apply_deadline_reached()  # pylint: disable=protected-access
-            return
         records_df = next(dataframe_generator)
         #logger.info(f"records returned from dataframe generator: {records_df}")
         if records_df is None:
@@ -1567,8 +1568,6 @@ def managed_outbound_processing(concurrency: int, batch_size: int):
     def actual_decorator(method):
         @wraps(method)
         def _impl(self: OmnataPlugin, *method_args, **method_kwargs):
-            logger.info(f"method_args: {method_args}")
-            logger.info(f"method_kwargs: {method_kwargs}")
             if self._sync_request is None:  # pylint: disable=protected-access
                 raise ValueError(
                     "To use the managed_outbound_processing decorator, you must attach a sync request to the plugin instance (via the _sync_request property)"
@@ -1667,10 +1666,6 @@ def __managed_inbound_processing_worker(
         logger.info(
             f"worker {worker_index} processing. Cancelled: {cancellation_token.is_set()}"
         )
-        if datetime.datetime.now(datetime.timezone.utc) > plugin_class_obj._sync_request._run_deadline:
-            # if we've reached the deadline for the run, end it
-            plugin_class_obj._sync_request.apply_deadline_reached()
-            return
         try:
             stream: StoredStreamConfiguration = streams_queue.get_nowait()
             logger.info(f"stream returned from queue: {stream}")
@@ -1714,8 +1709,6 @@ def managed_inbound_processing(concurrency: int):
     def actual_decorator(method):
         @wraps(method)
         def _impl(self:OmnataPlugin, *method_args, **method_kwargs):
-            logger.info(f"method_args: {method_args}")
-            logger.info(f"method_kwargs: {method_kwargs}")
             if self._sync_request is None:
                 raise ValueError(
                     "To use the managed_inbound_processing decorator, you must attach an apply request to the plugin instance (via the _sync_request property)"
