@@ -138,7 +138,7 @@ class PluginEntrypoint:
                 api_limits=api_limits,
                 rate_limit_state_all=rate_limit_state_all,
                 rate_limit_state_this_sync_and_branch=rate_limit_state_this_branch,
-                run_deadline=datetime.datetime.now(datetime.timezone.utc) + datetime.timedelta(hours=4),
+                run_deadline=datetime.datetime.now(datetime.timezone.utc) + datetime.timedelta(minutes=request.time_limit_mins),
                 development_mode=False,
             )
             try:
@@ -180,7 +180,7 @@ class PluginEntrypoint:
                 api_limits=api_limits,
                 rate_limit_state_all=rate_limit_state_all,
                 rate_limit_state_this_sync_and_branch=rate_limit_state_this_branch,
-                run_deadline=datetime.datetime.now(datetime.timezone.utc) + datetime.timedelta(hours=4),
+                run_deadline=datetime.datetime.now(datetime.timezone.utc) + datetime.timedelta(minutes=request.time_limit_mins),
                 development_mode=False,
                 streams=list(request.streams_configuration.included_streams.values()),
                 omnata_log_handler=omnata_log_handler
